/* sidebar.c generated by valac 0.25.1.6-a1f05, the Vala compiler
 * generated from sidebar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_WIZARD_SIDEBAR (boxes_wizard_sidebar_get_type ())
#define BOXES_WIZARD_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebar))
#define BOXES_WIZARD_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebarClass))
#define BOXES_IS_WIZARD_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SIDEBAR))
#define BOXES_IS_WIZARD_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SIDEBAR))
#define BOXES_WIZARD_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SIDEBAR, BoxesWizardSidebarClass))

typedef struct _BoxesWizardSidebar BoxesWizardSidebar;
typedef struct _BoxesWizardSidebarClass BoxesWizardSidebarClass;

#define BOXES_TYPE_PROPERTIES_SIDEBAR (boxes_properties_sidebar_get_type ())
#define BOXES_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebar))
#define BOXES_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))
#define BOXES_IS_PROPERTIES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_IS_PROPERTIES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_SIDEBAR))
#define BOXES_PROPERTIES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_SIDEBAR, BoxesPropertiesSidebarClass))

typedef struct _BoxesPropertiesSidebar BoxesPropertiesSidebar;
typedef struct _BoxesPropertiesSidebarClass BoxesPropertiesSidebarClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

typedef enum  {
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesSidebar {
	GtkRevealer parent_instance;
	BoxesSidebarPrivate * priv;
	BoxesWizardSidebar* wizard_sidebar;
	BoxesPropertiesSidebar* props_sidebar;
};

struct _BoxesSidebarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesSidebarPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkNotebook* notebook;
	BoxesAppWindow* window;
};


static gpointer boxes_sidebar_parent_class = NULL;
static BoxesUIIface* boxes_sidebar_boxes_ui_parent_iface = NULL;

GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_properties_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_SIDEBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SIDEBAR, BoxesSidebarPrivate))
enum  {
	BOXES_SIDEBAR_DUMMY_PROPERTY,
	BOXES_SIDEBAR_PREVIOUS_UI_STATE,
	BOXES_SIDEBAR_UI_STATE
};
void boxes_sidebar_setup_ui (BoxesSidebar* self, BoxesAppWindow* window);
void boxes_properties_sidebar_setup_ui (BoxesPropertiesSidebar* self, BoxesAppWindow* window);
static void boxes_sidebar_ui_state_changed (BoxesSidebar* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesSidebar* boxes_sidebar_new (void);
BoxesSidebar* boxes_sidebar_construct (GType object_type);
static GObject * boxes_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_sidebar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_sidebar_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_sidebar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_sidebar_page_get_type (void) {
	static volatile gsize boxes_sidebar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SIDEBAR_PAGE_WIZARD, "BOXES_SIDEBAR_PAGE_WIZARD", "wizard"}, {BOXES_SIDEBAR_PAGE_PROPERTIES, "BOXES_SIDEBAR_PAGE_PROPERTIES", "properties"}, {0, NULL, NULL}};
		GType boxes_sidebar_page_type_id;
		boxes_sidebar_page_type_id = g_enum_register_static ("BoxesSidebarPage", values);
		g_once_init_leave (&boxes_sidebar_page_type_id__volatile, boxes_sidebar_page_type_id);
	}
	return boxes_sidebar_page_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return self ? g_object_ref (self) : NULL;
#line 154 "sidebar.c"
}


void boxes_sidebar_setup_ui (BoxesSidebar* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesPropertiesSidebar* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (window != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = window;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->window);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->window = _tmp1_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp2_ = self->props_sidebar;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp3_ = window;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_properties_sidebar_setup_ui (_tmp2_, _tmp3_);
#line 181 "sidebar.c"
}


static void boxes_sidebar_ui_state_changed (BoxesSidebar* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = _tmp0_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (_tmp1_) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 200 "sidebar.c"
		{
			BoxesSidebarPage _tmp2_ = 0;
			BoxesUIState _tmp3_ = 0;
			BoxesUIState _tmp4_ = 0;
			GtkNotebook* _tmp5_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			gtk_revealer_set_reveal_child ((GtkRevealer*) self, TRUE);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp4_ = _tmp3_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			if (_tmp4_ == BOXES_UI_STATE_WIZARD) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp2_ = BOXES_SIDEBAR_PAGE_WIZARD;
#line 216 "sidebar.c"
			} else {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp2_ = BOXES_SIDEBAR_PAGE_PROPERTIES;
#line 220 "sidebar.c"
			}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp5_ = self->priv->notebook;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			g_object_set (_tmp5_, "page", (gint) _tmp2_, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 228 "sidebar.c"
		}
		default:
		{
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			gtk_revealer_set_reveal_child ((GtkRevealer*) self, FALSE);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 236 "sidebar.c"
		}
	}
}


BoxesSidebar* boxes_sidebar_construct (GType object_type) {
	BoxesSidebar * self = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) g_object_new (object_type, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return self;
#line 248 "sidebar.c"
}


BoxesSidebar* boxes_sidebar_new (void) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return boxes_sidebar_construct (BOXES_TYPE_SIDEBAR);
#line 255 "sidebar.c"
}


static BoxesUIState boxes_sidebar_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 271 "sidebar.c"
}


static void boxes_sidebar_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 286 "sidebar.c"
}


static BoxesUIState boxes_sidebar_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 302 "sidebar.c"
}


static void boxes_sidebar_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = value;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->_ui_state = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 317 "sidebar.c"
}


static void _boxes_sidebar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_ui_state_changed ((BoxesSidebar*) self);
#line 324 "sidebar.c"
}


static GObject * boxes_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSidebar * self;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	parent_class = G_OBJECT_CLASS (boxes_sidebar_parent_class);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_sidebar_ui_state_changed_g_object_notify, self, 0);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return obj;
#line 342 "sidebar.c"
}


static void boxes_sidebar_class_init (BoxesSidebarClass * klass) {
	gint BoxesSidebar_private_offset;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_parent_class = g_type_class_peek_parent (klass);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSidebarPrivate));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_sidebar_get_property;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_sidebar_set_property;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_sidebar_constructor;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_sidebar_finalize;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIDEBAR_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIDEBAR_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	BoxesSidebar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/sidebar.ui");
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_sidebar", FALSE, G_STRUCT_OFFSET (BoxesSidebar, wizard_sidebar));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_sidebar", FALSE, G_STRUCT_OFFSET (BoxesSidebar, props_sidebar));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "notebook", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, notebook));
#line 374 "sidebar.c"
}


static void boxes_sidebar_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->get_previous_ui_state = boxes_sidebar_real_get_previous_ui_state;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->set_previous_ui_state = boxes_sidebar_real_set_previous_ui_state;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->get_ui_state = boxes_sidebar_real_get_ui_state;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->set_ui_state = boxes_sidebar_real_set_ui_state;
#line 389 "sidebar.c"
}


static void boxes_sidebar_instance_init (BoxesSidebar * self) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv = BOXES_SIDEBAR_GET_PRIVATE (self);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_ensure (BOXES_TYPE_PROPERTIES_SIDEBAR);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SIDEBAR);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 402 "sidebar.c"
}


static void boxes_sidebar_finalize (GObject* obj) {
	BoxesSidebar * self;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->wizard_sidebar);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->props_sidebar);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->notebook);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->window);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (boxes_sidebar_parent_class)->finalize (obj);
#line 420 "sidebar.c"
}


GType boxes_sidebar_get_type (void) {
	static volatile gsize boxes_sidebar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSidebarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_sidebar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSidebar), 0, (GInstanceInitFunc) boxes_sidebar_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_sidebar_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_sidebar_type_id;
		boxes_sidebar_type_id = g_type_register_static (GTK_TYPE_REVEALER, "BoxesSidebar", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_sidebar_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_sidebar_type_id__volatile, boxes_sidebar_type_id);
	}
	return boxes_sidebar_type_id__volatile;
}


static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSidebar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (property_id) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_PREVIOUS_UI_STATE:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_UI_STATE:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 455 "sidebar.c"
		default:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 461 "sidebar.c"
	}
}


static void _vala_boxes_sidebar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSidebar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (property_id) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_PREVIOUS_UI_STATE:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_UI_STATE:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 483 "sidebar.c"
		default:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 489 "sidebar.c"
	}
}



